OpusInfo class final

Contains detailed information about an Opus audio stream

Constructors

OpusInfo({required int version, required int channels, required int preSkip, required int inputSampleRate, required int outputGain, required int mappingFamily, required int streamCount, required int coupledCount, required List<int> channelMapping, required int channelMappingSize})
Creates a new OpusInfo instance with the metadata fields

Properties

channelMapping List<int>
Channel mapping array defining how output channels are ordered
getter/setter pair
channelMappingSize int
Size of the channel mapping configuration
getter/setter pair
channels int
Number of channels in the Opus stream
getter/setter pair
coupledCount int
Number of stereo Opus streams Only used if mappingFamily is not 0
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputSampleRate int
Original input sampling rate in Hz before encoding
getter/setter pair
mappingFamily int
Mapping family type used for channel configuration
getter/setter pair
outputGain int
Output gain in Q8 format (signed fixed-point value in dB)
getter/setter pair
preSkip int
Number of samples to skip at the start of the stream for encoder delay compensation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamCount int
Number of independent Opus streams Only used if mappingFamily is not 0
getter/setter pair
version int
Version number for the Opus header format
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited