VorbisInfo class final

Contains detailed information about a Vorbis audio stream

Constructors

VorbisInfo({required int version, required int channels, required int rate, required int bitrateUpper, required int bitrateNominal, required int bitrateLower, required int bitrateWindow})
Creates a new VorbisInfo instance with the metadata fields

Properties

bitrateLower int
The lower limit of the bitrate for variable bitrate streams. For fixed bitrate streams, this will be equal to bitrateUpper and bitrateNominal.
getter/setter pair
bitrateNominal int
The target or average bitrate for the stream. For fixed bitrate streams, this will be equal to bitrateUpper and bitrateLower.
getter/setter pair
bitrateUpper int
The upper limit of the bitrate for variable bitrate streams. For fixed bitrate streams, this will be equal to bitrateNominal and bitrateLower.
getter/setter pair
bitrateWindow int
The size of the window used for bitrate tracking
getter/setter pair
channels int
The number of audio channels in the stream
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rate int
The sampling rate of the audio in Hz
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
The version of the Vorbis stream format
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited