AudioVisualizationData class
Audio visualization data produced by the SoLoud audio mixer.
Contains time-domain waveform samples and/or frequency-domain FFT bins for one or more audio channels.
Constructors
-
AudioVisualizationData({required int channelCount, required List<
Float32List> wave, required List<Float32List> fft}) -
Creates a visualization data packet.
const
Properties
- channelCount → int
-
The number of channels included in this visualization packet.
final
-
fft
→ List<
Float32List> -
Frequency-domain FFT magnitude data for each channel.
final
- fftData → Float32List?
-
Convenience getter to obtain the first (or merged) channel's FFT data.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
wave
→ List<
Float32List> -
Time-domain waveform data for each channel.
final
- waveData → Float32List?
-
Convenience getter to obtain the first (or merged) channel's wave data.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited