FlacInfo class final
Contains detailed information about an Flac audio stream
Constructors
Properties
- bitsPerSample ↔ int
-
The bitrate of the audio stream
getter/setter pair
- channels ↔ int
-
The number of audio channels in the stream
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBlockSize ↔ int
-
The maximum block size in samples
getter/setter pair
- maxFrameSize ↔ int
-
The maximum frame size in bytes
getter/setter pair
- minBlockSize ↔ int
-
The minimum block size in samples
getter/setter pair
- minFrameSize ↔ int
-
The minimum frame size in bytes
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
The sampling rate of the audio in Hz
getter/setter pair
- totalSamples ↔ int
-
The total number of samples in the audio stream
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited