Mp3Metadata class final
Represents metadata information extracted from an MP3 audio file
Constructors
- Mp3Metadata({required String title, required String artist, required String album, required String date, required String genre})
- Creates a new Mp3Metadata instance with the metadata fields
Properties
- album ↔ String
-
The album name containing this audio track
getter/setter pair
- artist ↔ String
-
The artist or performer of the audio track
getter/setter pair
- date ↔ String
-
The release date or year of the audio track
getter/setter pair
- genre ↔ String
-
The musical genre or style of the audio track
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
The title of the audio track
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited