ReadSamplesErrors enum
Possible read samples errors.
Values
- readSamplesNoError → const ReadSamplesErrors
-
No error
const ReadSamplesErrors(0) - noBackend → const ReadSamplesErrors
-
Initialization failed. Probably an unsupported format.
const ReadSamplesErrors(1) - failedToGetDataFormat → const ReadSamplesErrors
-
Failed to retrieve decoder data format.
const ReadSamplesErrors(2) - failedToSeekPcm → const ReadSamplesErrors
-
Failed to seek audio data.
const ReadSamplesErrors(3) - failedToReadPcmFrames → const ReadSamplesErrors
-
Failed to read PCM frames.
const ReadSamplesErrors(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The integer value of the error. This is the same number that is returned
from the C++ API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → ReadSamplesErrors -
Returns a ReadSamplesErrors from a
value.
Constants
-
values
→ const List<
ReadSamplesErrors> - A constant List of the values in this enum, in order of their declaration.