startMixerOutputStream method
Captures the master mixer output as a Stream of Uint8List chunks.
This method has the same behavior as SoLoud.startMixerOutputStream but can be called from a non-main isolate. The engine must have been initialized in the main isolate before calling this method.
See SoLoud.startMixerOutputStream for parameter details.
Implementation
@experimental
Stream<Uint8List> startMixerOutputStream({
MixerOutputFormat format = MixerOutputFormat.pcmF32le,
int sampleRate = -1,
int channels = -1,
int bufferSizeBytes = 1024 * 1024,
int notificationThresholdBytes = 4096,
int chunkPCMFrames = -1,
}) => _mixerOutputStreamManager.start(
format: format,
sampleRate: sampleRate,
channels: channels,
bufferSizeBytes: bufferSizeBytes,
notificationThresholdBytes: notificationThresholdBytes,
chunkPCMFrames: chunkPCMFrames,
);