SoLoudStreamEndedAlreadyCppException class
Trying to add PCM data but the stream is marked to be ended already, by the user or when the stream reached its maximum capacity, in this case the stream is automatically marked to be ended.
- Inheritance
-
- Object
- SoLoudException
- SoLoudCppException
- SoLoudStreamEndedAlreadyCppException
Constructors
- SoLoudStreamEndedAlreadyCppException([String? message])
-
Creates a new SoLoudStreamEndedAlreadyCppException.
const
Properties
- description → String
-
A verbose description of what this exception means, in general.
Don't confuse with the optional message parameter, which is there
to explain what exactly went wrong in that particular case.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
A message that explains what exactly went wrong in that particular case.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited